@@ -7,23 +7,11 @@ To get known about access log, see Apache HTTP server official document.
 [`en <http://httpd.apache.org/docs/2.4/en/logs.html>`_]
 [`ja <http://httpd.apache.org/docs/2.4/ja/logs.html>`_]
 
-Most simple script is::
+This module is also executable to parse access log record.
 
-    #!/usr/bin/env python
-    # -*- coding: utf-8 -*-
+.. code-block:: bash
 
-    from pprint import pprint
-
-    from clitool.cli import climain
-    from clitool.accesslog import logparse
-
-    @climain
-    def main(output, **kwargs):
-        stats, report = logparse(**kwargs)
-        pprint(report, stream=output)
-
-    if __name__ == '__main__':
-        main()
+    $ tail -f /var/log/httpd/access_log | python -m clitool.accesslog
 
 """
 
@@ -142,11 +130,38 @@ def logparse(*args, **kwargs):
 
 
 if __name__ == '__main__':
-    import json
-    from clitool.cli import parse_arguments
+    from six import print_
+    from clitool.cli import parse_arguments, clistream
 
-    args = parse_arguments(files=dict(nargs='*'))
-    stats, report = logparse(files=args.files)
-    json.dump({'stats': stats, 'report': report}, args.output, indent=2)
+    RED = '\033[91m'
+    PURPLE = '\033[95m'
+    END = '\033[0m'
+
+    args = parse_arguments(files=dict(nargs='*'),
+                color=dict(flags="--color", action="store_true"),
+                status=dict(flags="--status"))
+
+    lst = map(int, args.status.split(',')) if args.status else None
+
+    def p(e):
+        if lst and not e['response_status'] in lst:
+            return
+        colored = False
+        if args.color:
+            if e['response_status'] >= 500:
+                print_(RED, end='')
+                colored = True
+            if e['response_status'] >= 400:
+                print_(PURPLE, end='')
+                colored = True
+        for k in sorted(e.keys()):
+            if e[k]:
+                print_("%-16s: %s" % (k, e[k]))
+        if colored:
+            print_(END, end='')
+        print_("-" * 40)
+
+    stats = clistream(p, logentry, files=args.files)
+    print_(stats)
 
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
