@@ -173,6 +173,8 @@ def cliconfig(fp, env=None):
 
     :param fp: opened file pointer of configuration
     :type fp: FileType
+    :param env: environment to load
+    :type env: str
     :rtype: dict
     """
     if fp is None:
